search Package
==============

:mod:`interfaces` Module
------------------------

.. automodule:: CMFDefault.browser.search.interfaces
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`search` Module
--------------------

.. automodule:: CMFDefault.browser.search.search
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`vocab` Module
-------------------

.. automodule:: CMFDefault.browser.search.vocab
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    CMFDefault.browser.search.tests

